@@ -1,4 +1,5 @@
 import abc
+import json
 
 from controller import Radar, RadarTarget
 from flockai.interfaces.drone import IDrone
@@ -71,27 +72,19 @@ class AutopilotControlledDrone(IDrone, abc.ABC):
         In case we are on the target no input is given
         :return:
         """
-        # self.simulation_step += 1
-        # if self.simulation_step % 5 == 0:
-        #     if self.target_has_reached():
-        #         return 0, 0, 0
-        #
-        #     if self.on_track():
-        #         self.simulation_step -= 1
-        #         return 0, 2, 0
-        #
-        #     return 0, 0, 2.3
-        # return 0, 0, 0
-        # print("\033c", end="")
-
         radar: Radar = self.devices['radar']['device']
         total_targets = radar.getNumberOfTargets()
         targets = radar.getTargets()
-        # print('Currently seeing', total_targets, 'targets')
+
         if total_targets > 0:
             self.target_id_count += 1
-            # for i in range(total_targets):
-            #     print(f'--target {i}: distance = {targets[i].distance} azimuth = {targets[i].azimuth}')
+            for i in range(total_targets):
+                print(f'--target {i}: distance = {targets[i].distance} azimuth = {targets[i].azimuth}')
+                if targets[i].distance < 2.5:
+                    print('emitting')
+                    emitter = self.devices['emitter']['device']
+                    message = 'DESTINATION_ARRIVED'
+                    emitter.send(message.encode('utf-8'))
 
             if self.target_id_count == 1:
                 self.multiplier *= -1
@@ -99,9 +92,4 @@ class AutopilotControlledDrone(IDrone, abc.ABC):
         else:
             self.target_id_count = 0
             return 0, 0, self.multiplier * 0.4
-        # # # Transform the keyboard input to disturbances on the stabilization algorithm.
-        # roll_disturbance = 0
-        # pitch_disturbance = 0
-        # yaw_disturbance = 0
-        #
-        # return roll_disturbance, pitch_disturbance, yaw_disturbance
+            # return roll_disturbance, pitch_disturbance, yaw_disturbance
