@@ -1,3 +1,6 @@
+from PIL import Image
+from dlib import cnn_face_detection_model_v1
+
 from controller import Emitter, Camera, GPS, Gyro
 from flockai.PyCatascopia.probelib.ProcessProbe import ProcessProbe
 from flockai.models.drones.autopilot_controlled_drone import AutopilotControlledDrone
@@ -10,6 +13,8 @@ from flockai.models.devices.device_enums import EnableableDevice, NonEnableableD
 from flockai.utils.intensive_thread import IntensiveThread
 import numpy as np
 import json
+import time
+
 
 class KeyboardMavic2DJI(KeyboardControlledDrone):
     """
@@ -95,7 +100,7 @@ class KeyboardMavic2DJI(KeyboardControlledDrone):
             led_on = not led_on
 
     def get_image_vector_every(self, n):
-        t = self.getTime() % 5.0
+        t = self.getTime() % n
         if t != 0.0:
             return []
 
@@ -132,8 +137,6 @@ class KeyboardMavic2DJI(KeyboardControlledDrone):
 
         total_energy = 0
         net_transaction_time = 0
-        temperature_sensor = TemperatureSensor('data/temperature_data.txt')
-        humidity_sensor = HumiditySensor('data/humidity_data.txt')
 
         while self.step(self.basic_time_step) != -1:
             # Blink lights
@@ -144,13 +147,9 @@ class KeyboardMavic2DJI(KeyboardControlledDrone):
             # Get battery data
             # print(self.batterySensorGetValue())
 
-            # Do an intensive task
-            # t = IntensiveThread()
-            # t.run()
-
             # Send messages
-            image_rgb_vector = self.get_image_vector_every(5)
-            transmit_time = self.send_msg(image_rgb_vector, emitter_devices)
+            # image_rgb_vector = self.get_image_vector_every(5)
+            # transmit_time = self.send_msg(image_rgb_vector, emitter_devices)
             # print("Transmit time:", transmit_time)
 
             # Receive messages
@@ -166,12 +165,11 @@ class KeyboardMavic2DJI(KeyboardControlledDrone):
             total_energy += flight_time * self.DJI_A3_FC
             # print("Total energy consumed:", total_energy)
 
-            humidity_max, humidity_min, humidity_avg = humidity_sensor.get_values()
-            temperature_max, temperature_min, temperature_avg = temperature_sensor.get_values()
-
-            input_vector = np.array([[temperature_max], [temperature_min], [temperature_avg],
-                                     [humidity_max], [humidity_min], [humidity_avg]]).reshape(1, -1)
-            # print(self.model.predict(input_vector))
+            # get image in png format
+            if self.model is not None:
+                prediction = self.model.predict()
+                if prediction is not None:
+                    print(prediction)
 
 
 class AutopilotMavic2DJI(AutopilotControlledDrone):
@@ -182,18 +180,39 @@ class AutopilotMavic2DJI(AutopilotControlledDrone):
         self.RASPBERRY_PI_4B_ACTIVE = 8
         super().__init__(devices)
 
-
-
     def get_angular_velocity(self):
         gyro: Gyro = self.devices['gyro']['device']
         return gyro.getValues()
 
+    def send_msg(self, msg, emitter_devices: list):
+        """
+        Sends a message from the attached emitter device
+        :param emitter_devices: The emitter devices to send the message
+        :param msg: The message to send
+        :return: None
+        """
+        total_time = 0
+
+        for emitter in emitter_devices:
+            if emitter not in self.devices:
+                print(f"The specified emitter device is not found: {emitter}")
+                return 0
+            f_emitter = self.devices[emitter]['device']
+
+
+        return total_time
+
     def run(self):
         # Wait a second before starting
         while self.step(self.basic_time_step) != -1:
             if self.getTime() > 1:
                 break
 
+        emitter_devices = []
+        for device_name in self.devices:
+            if self.devices[device_name]['type'] == NonEnableableDevice.EMITTER:
+                emitter_devices.append(device_name)
+
         while self.step(self.basic_time_step) != -1:
             # For now just actuate
             # print(self.get_distance_from_target())
